import click 
from app.plugin import davinci
from app.file_service import file_prompt

def index(text_input : str) -> str:
    return davinci(text_input)


def prompt() -> None:
    resp = "begin"

    while len(resp) > 0:

        client = input(" Dîtes quelque chose (q : quitter , m : modifier api_key ) > ")

        if client == "q":
            break
        
        elif client == "m":
            
            file_prompt()
            break

        resp = index(client)

        if resp == None:
            break
        
        click.echo("----------------------------------------------------------")
        click.echo(f"<< 🤖 >> {resp}")
        click.echo("\n")
        click.echo("----------------------------------------------------------")



import click , os
from app.main import prompt
from app.file_service import file_prompt

@click.group()
def cli():
    pass

@cli.command()
@click.option('-n', '--name', type=str, help='Name to greet', default='World')
def hello(name):
    click.echo(f'Hello {name}')

@cli.command()
def tellme():
    
    if not os.path.isfile(".env"): 

        file_prompt()
    else:

        prompt()
        


        

         




import os, click
from typing import Union
import openai
from app.file_service import file_prompt
from dotenv import load_dotenv
load_dotenv()

openai.api_key = os.getenv("OPENAI_API_KEY")

def davinci(what : str) -> Union[str, None]:

    try:
        response = openai.Completion.create(
        model="text-davinci-003",
        prompt=f"The following is a conversation with an AI. The AI is helpful, creative, clever, and very friendly.\n\nHuman:{what}",
        temperature=0.9,
        max_tokens=200,
        top_p=1.0,
        frequency_penalty=0.0,
        presence_penalty=0.6,
        stop=[" Human:", " AI:"]
        )
        
        res = response["choices"][0]["text"].replace("AI:","")

    
    except openai.error.AuthenticationError:

        modify_apikey = input("Votre API KEY est incorrect, tapez `m` pour modifer le key , ou `q` pour quitter > ")

        if modify_apikey == "m" :

            file_prompt()
            res = None
            
        else:

            res = None
            

    return res


import click , os , getpass ,dotenv

def file_prompt() -> None:
    
    api_key = getpass.getpass(" Ajoutez votre api key (invisible input) > ")
    
    if api_key :

        fichier = open(".env", "w")
        fichier.close()
        dotenv.set_key(".env", "OPENAI_API_KEY", api_key)

        click.echo("Votre API KEY a bien été ajouté , veuillez relancer la commande `cgpt tellme` ")

    elif api_key =="" or not api_key:

        click.echo("\n Vous n' avez pas ajouter un API KEY \n")


from setuptools import setup, find_packages

with open("pypi_desc.md", "r", encoding="utf-8") as fh:
    long_desc = fh.read()
    
with open("requirements.txt", "r", encoding="utf-8") as fh:
    requirements = fh.read()
    
setup(
    name = 'cgpt',
    version = '0.1.21',
    author = 'Aina Yves',
    author_email = 'randrianaina.yves@gmail.com',
    license = 'MIT',
    description = 'Use openai chat-gpt on your cli',
    long_description=long_desc,
    url = 'https://github.com/Aina15-DT/cli-gpt>',
    long_description_content_type='text/markdown',
    py_modules = ['cgpt','app'],
    packages = find_packages(),
    install_requires = ['setuptools',
                        'twine',
                        'click>=7.1.2',
                        'openai',
                        'python-dotenv'],
                        
    python_requires='>=3.7',
    classifiers=[
        "Programming Language :: Python :: 3.8",
        "Operating System :: OS Independent",
    ],
    entry_points = '''
        [console_scripts]
        cgpt=cgpt:cli
    '''
)